function [results, roc_curves] = MCRalgorithm(x_train, y_train, t_train, x_test, y_test, t_test, config)

if(isfield(config, 'l2normweight'))
    l2normweight = config.l2normweight;
else
    l2normweight = 1000;
end

if(isfield(config, 'l1normweight'))
    l1normweight = config.l1normweight;
else
    l1normweight = 0.1;
end

C = config.Cvalue;

x_train = add_constant_term(x_train);
x_test = add_constant_term(x_test);

n = size(x_train, 2);
m = sum(y_train~=1);

results.train_auc = zeros(length(C), 1);
results.test_auc = zeros(length(C), 1);

y_train_1 = (t_train(y_train==1))/max(t_train);
y_train_1 = log((y_train_1+eps).^-1);
x_train_1 = x_train(y_train==1, :);
x_train_0 = x_train(y_train~=1, :);
roc_curves = cell(1, length(C));

for i=1:length(C)
    cvx_begin quiet
        variables w(n) xi(m) hi(m)
        minimize sum(huber(x_train_1*w-y_train_1,1)) + C(i)*sum(xi) + l2normweight*sum(w.^2) + l1normweight*norm(w, 1)
        subject to
            x_train_0*w<=-1+xi;
            xi>=0;
    cvx_end
    train_prediction = x_train*w;
    test_prediction = x_test*w;
    results.train_auc(i) = roc_opt(y_train, train_prediction);
    results.test_auc(i) = roc_opt(y_test, test_prediction);
    roc_curves{i} = roc2([test_prediction, y_test], 0.05, config.verbose);
    results.train_ci(i) = concordance_index(t_train, y_train, exp(-train_prediction));
    results.test_ci(i) = concordance_index(t_test, y_test, exp(-test_prediction));
    if(config.verbose)
        disp(['Train AUC: ' num2str(results.train_auc(i)) ', Test AUC: ' num2str(results.test_auc(i)) ', Train CI: ' num2str(results.train_ci(i)) ', Test CI: ' num2str(results.test_ci(i))]);
    end
end

